==> diskus-0.7.0.tar.gz: diskus-0.7.0/CHANGELOG.md <==
# unreleased

## Changes


## Features


## Bugfixes


## Other


## Packaging

# v0.6.0

- Updated dependencies

# v0.6.0

## Changes

There is an important change in default behavior: `diskus` will now report "disk usage" instead of "apparent file size", in analogy to what `du -sh` does.

At the same time however, we introduce a new `-b`/`--apparent-size` option which can be used to switch back to apparent file size (in analogy to what `du -sbh` does).

see #25

## Features

- `diskus` is now available for Windows, see #32 (@fawick)
- Error messages are now hidden by default and can be re-enabled via `--verbose`, see #34 (@wngr)
- Added a new `--size-format <type>` option which can be used to switch from decimal to binary exponents (MiB instead of MB).
- `diskus` changes its output format when the output is piped to a file or to another program. It will simply print the number of bytes, see #35
- Added a new `-b`/`--apparent-size` option which can be used to switch from "disk usage" to "apparent size" (not available on Windows)

## Other

- diskus is now in the official Arch repositories, see #24 (@polyzen)
- diskus is now available on NixOS, see #26 (@fuerbringer)
- diskus is now available on Homebrew and MacPorts, see #33 (@heimskr)
- Added a man page

# v0.5.0

- Expose diskus internals as a library, see #21 (@amilajack)

# v0.4.0

- More performance improvements by using a custom parallel directory-walker, see #15

# v0.3.1

# v0.3.0

- Renamed the project to diskus

# v0.2.0

- Fine-tuned number of threads (makes is even faster)

# v0.1.0

Initial release

==> diskus-0.9.0.tar.gz: diskus-0.9.0/CHANGELOG.md <==
# v0.9.0


## Features

- Added `--directories` option with values `auto`/`included`/`excluded` to control whether directory sizes are counted
- Added `apparent_size()` builder method as shorthand for `.count_type(CountType::ApparentSize)`

## Bugfixes

- Fixed directory counting to match `du` behavior:
  - Disk usage mode: directories are included (matches `du -s`)
  - Apparent size mode: directories are excluded (matches `du -sb`)

## Library

- **Breaking**: Complete redesign of the API
  - Renamed `Walk` to `DiskUsage`
  - Renamed `FilesizeType` to `CountType`
  - Changed to a builder pattern: `DiskUsage::new(&paths).apparent_size().count()`
  - `count()` now returns a `DiskUsageResult` struct instead of a tuple
  - `new()` now accepts `impl IntoIterator<Item = P>` where `P: AsRef<Path>`
- Default number of workers (3× CPU cores) is now set in the library, not the CLI


# v0.8.0

## Changes

- Updated Rust edition from 2018 to 2021
- Updated dependencies
- CI fixes

# v0.7.0

## Changes

- Migrated CI from Travis to GitHub Actions
- Added CHANGELOG file
- Updated dependencies

# v0.6.0

## Changes

There is an important change in default behavior: `diskus` will now report "disk usage" instead of "apparent file size", in analogy to what `du -sh` does.

At the same time however, we introduce a new `-b`/`--apparent-size` option which can be used to switch back to apparent file size (in analogy to what `du -sbh` does).

see #25

## Features

- `diskus` is now available for Windows, see #32 (@fawick)
- Error messages are now hidden by default and can be re-enabled via `--verbose`, see #34 (@wngr)
- Added a new `--size-format <type>` option which can be used to switch from decimal to binary exponents (MiB instead of MB).
- `diskus` changes its output format when the output is piped to a file or to another program. It will simply print the number of bytes, see #35
- Added a new `-b`/`--apparent-size` option which can be used to switch from "disk usage" to "apparent size" (not available on Windows)

## Other

- diskus is now in the official Arch repositories, see #24 (@polyzen)
- diskus is now available on NixOS, see #26 (@fuerbringer)
- diskus is now available on Homebrew and MacPorts, see #33 (@heimskr)
- Added a man page

# v0.5.0

- Expose diskus internals as a library, see #21 (@amilajack)

# v0.4.0

- More performance improvements by using a custom parallel directory-walker, see #15

# v0.3.1

# v0.3.0

- Renamed the project to diskus

# v0.2.0

- Fine-tuned number of threads (makes is even faster)

# v0.1.0

Initial release
